#[repr(transparent)]pub struct SidebarItemList {
inner: TypedObjectRef<SidebarItemList, ()>,
phantom: PhantomData<()>,
}Expand description
Fixed list of all subcomponents in the sidebar.
Implements the gio::ListModel interface and yields the top-level
items of the sidebar.
GLib type: GObject with reference counted clone semantics.
Fields
inner: TypedObjectRef<SidebarItemList, ()>phantom: PhantomData<()>Implementations
Sourceimpl SidebarItemList
impl SidebarItemList
Sourcepub fn verification_list(
&self,
) -> <OnceCell<VerificationList> as Property>::Value
pub fn verification_list( &self, ) -> <OnceCell<VerificationList> as Property>::Value
The list of verification requests.
Sourcepub fn connect_room_list_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_room_list_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the room-list property
Sourcepub fn connect_verification_list_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_verification_list_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the verification-list property
Sourcepub fn notify_room_list(&self)
pub fn notify_room_list(&self)
Notify listeners of a change in the room-list property
Sourcepub fn notify_verification_list(&self)
pub fn notify_verification_list(&self)
Notify listeners of a change in the verification-list property
Sourceimpl SidebarItemList
impl SidebarItemList
Sourcepub fn new(room_list: &RoomList, verification_list: &VerificationList) -> Self
pub fn new(room_list: &RoomList, verification_list: &VerificationList) -> Self
Construct a new SidebarItemList with the given room list and
verification list.
Sourcepub(crate) fn set_show_all_for_room_category(
&self,
category: Option<RoomCategory>,
)
pub(crate) fn set_show_all_for_room_category( &self, category: Option<RoomCategory>, )
Set the room category to show all compatible sections and icon items for.
Sourcepub(crate) fn inhibit_expanded(&self, inhibit: bool)
pub(crate) fn inhibit_expanded(&self, inhibit: bool)
Set whether to inhibit the expanded state of the sections.
It means that all the sections will be expanded regardless of their “is-expanded” property.
Sourcepub(crate) fn section_from_room_category(
&self,
category: RoomCategory,
) -> Option<SidebarSection>
pub(crate) fn section_from_room_category( &self, category: RoomCategory, ) -> Option<SidebarSection>
Returns the SidebarSection for the given room category.